//-----------------------------------------------------------------------------
// LOGGER.H
// By Dean Harding
// 
// Copyright (c) 2000/2001 Dean Harding
//-----------------------------------------------------------------------------
#pragma once

#include <tchar.h>

//-----------------------------------------------------------------------------
#ifdef LOGGER_EXPORTS
#define LOGGER_API	__declspec(dllexport)
#else
#define LOGGER_API	__declspec(dllimport)
#endif

//-----------------------------------------------------------------------------
// The logger can print a number of things along with the actual line it's
// logging.  These are what it can also print

#define LOG_TIMESTAMP			1	// the time the line was logged
#define LOG_PROCNAME			2	// the name of the process that logged the
									// line.  This can be set with
									// CLogger::SetName()
#define LOG_THREADID			4	// the thread ID that logged this line

//-----------------------------------------------------------------------------
// Maximum length of a line
#define LOG_MAX_LINE			256

//-----------------------------------------------------------------------------
class LOGGER_API CLogger
{
public:
	// Initialize the logger.  This must be called before any calls to Attach()
	// (and it must have completed before any calls to Attach as well.
	static void Initialize();

	// Shutdown the logger.  Any loggers that have been created will become
	// invalid!
	static void Shutdown();

	// Attach to the logger.  This just creates a new CLogger class for you to
	// use.
	static CLogger *Attach( TCHAR *szLogFile = _T("errors.log") );

	// When you're finished logging, call this to destroy the CLogger class.
	virtual void Release() = 0;

	// Sets/Gets the current things that are printed along with actual line.
	virtual void SetFormat( DWORD dwFormat ) = 0;
	virtual DWORD GetFormat() = 0;

	// set/get the name displayed by LOG_PROCNAME.  If NULL is given, then we
	// use the name of the executable this process is running from (eg
	// myapp.exe)
	virtual void SetName( TCHAR *szName ) = 0;
	virtual TCHAR *GetName() = 0;

	// this is the big one!  This actually writes a line to the log file.
	virtual void Print( TCHAR *szFormat, ... ) = 0;
};


//-----------------------------------------------------------------------------
// End of LOGGER.H
//-----------------------------------------------------------------------------
